import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleBand,
  scaleLinear,
  max,
  format
} from 'd3';
import { message } from './message.js';
import { useData } from './useData.js';
import { AxisBottom } from './AxisBottom.js';
import { AxisLeft } from './AxisLeft.js';
import { Marks } from './Marks.js';

const csvUrl =
  'https://gist.githubusercontent.com/curran/0ac4077c7fc6390f5dd33bf5c06cb5ff/raw/605c54080c7a93a417a3cea93fd52e7550e76500/UN_Population_2019.csv';
const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 40,
  left: 200,
};

const App = () => {
  const data = useData();
  const innerHeight =
    height - margin.top - margin.bottom;
  const innerWidth =
    width - margin.left - margin.right;

  if (!data) {
    return <pre>Loading ... </pre>;
  }
  
  const xAxisTickFormat = (n) => format('.2s')(n).replace('G', 'B');
  const yValue = d => d.Country
  const xValue = d => d.Population
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
  	.padding(0.25);
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
        />
        <AxisLeft yScale={yScale} />
        <text className="axis-label" x={innerWidth / 2}>Population</text>
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);
